@@ -20,7 +20,7 @@
 
 ;; Balloon help pops up a small frame to display help text
 ;; relating to objects that the mouse cursor passes over.
-;; 
+;;
 ;; Installation:
 ;;
 ;; Byte-compile the file balloon-help.el (with M-x byte-compile-file)
@@ -57,11 +57,21 @@
   "Balloon-help support in XEmacs"
   :group 'frames)
 
-(defvar balloon-help-version "1.07"
+(defvar balloon-help-version "1.08"
   "Version string for Balloon Help.")
 
-(defvar balloon-help-mode nil
-  "*Non-nil means Balloon help mode is enabled.")
+;;;###autoload
+(defcustom balloon-help-mode nil
+  "*Non-nil means Balloon help mode is enabled."
+  :type 'boolean
+  :set (lambda (symbol value) (balloon-help-mode (or value 0)))
+  :initialize 'custom-initialize-default
+  :require 'balloon-help
+  :group 'balloon-help)
+
+(defvar balloon-help-minor-mode nil
+  "*Non-nil means Balloon help minor mode is enabled.")
+(make-variable-buffer-local 'balloon-help-minor-mode)
 
 (defcustom balloon-help-timeout 1500
   "*Display help after this many milliseconds of mouse inactivity."
@@ -167,6 +177,7 @@ has been loaded.")
 as the X server gets around to displaying it.  Nil means it
 will be invisible as soon as the X server decides to hide it.")
 
+;;;###autoload
 (defun balloon-help-mode (&optional arg)
   "Toggle Balloon Help mode.
 With arg, turn Balloon Help mode on iff arg is positive.
@@ -175,8 +186,10 @@ With Balloon Help enabled, a small frame is displayed whenever
 the mouse rests on an object that has a help property of some
 kind.  The text of that help property is displayed in the frame.
 
-For extents, the 'balloon-help' property is
-checked.
+If you want Balloon Help mode enabled in some buffers only, use
+`balloon-help-minor-mode' instead.
+
+For extents, the 'balloon-help' property is checked.
 
 For toolbar buttons, the help-string slot of the toolbar button
 is checked.
@@ -193,6 +206,23 @@ used as the help message."
   (if (null balloon-help-mode)
       (balloon-help-undisplay-help)))
 
+;;;###autoload
+(defun balloon-help-minor-mode (&optional arg)
+  "Toggle Balloon Help minor mode.
+With arg, turn Balloon Help minor mode on iff arg is positive.
+
+This minor mode is useful if you want `balloon-help-mode' globally disabled,
+except in some buffers.
+
+Please refer to the function `balloon-help-mode' for more details"
+  (interactive "P")
+  (setq balloon-help-minor-mode
+	(or (and arg (> (prefix-numeric-value arg) 0))
+	    (and (null arg) (null balloon-help-minor-mode))))
+  (if (and (null balloon-help-minor-mode) (null balloon-help-mode))
+      (balloon-help-undisplay-help)))
+(add-minor-mode 'balloon-help-minor-mode " Bal")
+
 (defun balloon-help-displayed ()
   (and (frame-live-p balloon-help-frame)
        (frame-visible-p balloon-help-frame)
@@ -215,7 +245,7 @@ This command must be bound to a mouse event."
 
 (defun balloon-help-motion-hook (event)
   (cond
-   ((null balloon-help-mode) t)
+   ((and (null balloon-help-mode) (null balloon-help-minor-mode)) t)
    (t
     (let* ((buffer (if event (event-buffer event) (current-buffer)))
 	   (frame (if event (event-frame event) (selected-frame)))
