@@ -8,6 +8,7 @@
 (custom-add-loads 'extensions '("iswitchb" "page-ext" "tempo"))
 (custom-add-loads 'recent-files-menu '("recent-files"))
 (custom-add-loads 'mouse '("avoid" "id-select" "outl-mouse"))
+(custom-add-loads 'convenience '("power-macros"))
 (custom-add-loads 'menu '("recent-files"))
 (custom-add-loads 'minibuffer '("detached-minibuf" "icomplete" "savehist"))
 (custom-add-loads 'environment '("popper"))
@@ -40,6 +41,7 @@
 (custom-add-loads 'iswitchb '("iswitchb"))
 (custom-add-loads 'fume '("func-menu"))
 (custom-add-loads 'blink-cursor '("blink-cursor"))
+(custom-add-loads 'power-macros '("power-macros"))
 (custom-add-loads 'files '("after-save-commands" "recent-files" "where-was-i-db"))
 (custom-add-loads 'fast-lock '("fast-lock"))
 (custom-add-loads 'font-lock '("lazy-lock"))
