@@ -69,7 +69,7 @@ Minibuffer completion history for `manual-entry'.")
 (defcustom Manual-snip-subchapter
   (not (string-match "solaris" system-configuration))
   "*Should man look in chapter 3 for ctime(3c)?
-This is relavent for Solaris and, perhaps, other systems which have 
+This is relevant for Solaris and, perhaps, other systems which have 
 `man -s 3' not find things in chapter 3c, or other such sub-chapters"
   :type 'boolean
   :group 'man)
@@ -78,7 +78,7 @@ This is relavent for Solaris and, perhaps, other systems which have
   (if (featurep 'mule)
       "\\cj"
     nil)
-"Regexp to matche bold two-column character.
+"Regexp to match bold two-column character.
 
 For compatibility with Japanese nroff, which puts one backspace in for
 each nominal column to create a bold character.  Ie, a bold kanji
@@ -184,19 +184,37 @@ potentially taking a long time."
     (define-key m 'button3 'Manual-popup-menu)
     m))
 
+(defvar Manual-mode-syntax-table nil
+  "Syntax table used in Manual-mode buffers")
+(if Manual-mode-syntax-table
+    ()
+  (setq Manual-mode-syntax-table (make-syntax-table))
+  (modify-syntax-entry ?: "_" Manual-mode-syntax-table)
+  (modify-syntax-entry ?+ "." Manual-mode-syntax-table)
+  (modify-syntax-entry ?- "." Manual-mode-syntax-table)
+  (modify-syntax-entry ?/ "." Manual-mode-syntax-table)
+  (modify-syntax-entry ?* "." Manual-mode-syntax-table)
+  )
+
 ;;;###autoload
 (defun manual-entry (topic &optional arg silent)
   "Display the Unix manual entry (or entries) for TOPIC."
   (interactive
-   (list (let* ((fmh "-A-Za-z0-9_.:()")
-		(default (save-excursion
+   (list (let* ((default (save-excursion
 			   (buffer-substring
 			    (progn
-			      (re-search-backward "\\sw" nil t)
-			      (skip-chars-backward fmh) (point))
+                              (if (not (eobp))
+                                  (forward-char))
+                              (if (re-search-backward "\\sw\\|\\s_" nil t)
+                                  (forward-char))
+                              (re-search-backward
+                               "\\(\\sw\\|\\s_\\)([0-9]+[A-Za-z]*\\=" nil t)
+                              (skip-syntax-backward "w_")
+                              (point))
 			    (progn
-                              (skip-chars-forward fmh)
-                              (skip-chars-backward ".") (point)))))
+                              (skip-syntax-forward "w_")
+                              (re-search-forward "\\=([0-9]+[A-Za-z]*)" nil t)
+                              (point) ))))
 		(thing (read-string
 			(if (equal default "") "Manual entry: "
 			  (concat "Manual entry: (default " default ") "))
@@ -303,6 +321,7 @@ potentially taking a long time."
   (kill-all-local-variables)
   (setq buffer-read-only t)
   (use-local-map Manual-mode-map)
+  (set-syntax-table Manual-mode-syntax-table)
   (setq major-mode 'Manual-mode
 	mode-name "Manual")
   ;; man pages with long lines are buggy!
